@@ -15,15 +15,16 @@
 import abc
 import datetime
 from distutils import versionpredicate
-
+import re
 
 import copy
 import iso8601
+import netaddr
 from oslo_utils import strutils
 from oslo_utils import timeutils
 import six
 
-from oslo_versionedobjects._i18n import _
+from oslo_versionedobjects._i18n import _, _LE
 from oslo_versionedobjects import _utils
 from oslo_versionedobjects import exception
 
@@ -308,6 +309,19 @@ class UUID(FieldType):
         return str(value)
 
 
+class MACAddress(FieldType):
+
+    _REGEX = re.compile(r'[0-9a-f]{2}(:[0-9a-f]{2}){5}$')
+
+    @staticmethod
+    def coerce(obj, attr, value):
+        lowered = value.lower().replace('-', ':')
+        if (not isinstance(value, six.string_types) or
+                not MACAddress._REGEX.match(lowered)):
+            raise ValueError(_LE("Malformed MAC %s"), value)
+        return lowered
+
+
 class Integer(FieldType):
     @staticmethod
     def coerce(obj, attr, value):
@@ -367,6 +381,71 @@ class DateTime(FieldType):
         return _utils.isotime(value)
 
 
+class IPAddress(FieldType):
+    @staticmethod
+    def coerce(obj, attr, value):
+        try:
+            return netaddr.IPAddress(value)
+        except netaddr.AddrFormatError as e:
+            raise ValueError(six.text_type(e))
+
+    def from_primitive(self, obj, attr, value):
+        return self.coerce(obj, attr, value)
+
+    @staticmethod
+    def to_primitive(obj, attr, value):
+        return str(value)
+
+
+class IPV4Address(IPAddress):
+    @staticmethod
+    def coerce(obj, attr, value):
+        result = IPAddress.coerce(obj, attr, value)
+        if result.version != 4:
+            raise ValueError(_('Network "%(val)s" is not valid '
+                               'in field %(attr)s') %
+                             {'val': value, 'attr': attr})
+        return result
+
+
+class IPV6Address(IPAddress):
+    @staticmethod
+    def coerce(obj, attr, value):
+        result = IPAddress.coerce(obj, attr, value)
+        if result.version != 6:
+            raise ValueError(_('Network "%(val)s" is not valid '
+                               'in field %(attr)s') %
+                             {'val': value, 'attr': attr})
+        return result
+
+
+class IPNetwork(IPAddress):
+    @staticmethod
+    def coerce(obj, attr, value):
+        try:
+            return netaddr.IPNetwork(value)
+        except netaddr.AddrFormatError as e:
+            raise ValueError(six.text_type(e))
+
+
+class IPV4Network(IPNetwork):
+    @staticmethod
+    def coerce(obj, attr, value):
+        try:
+            return netaddr.IPNetwork(value, version=4)
+        except netaddr.AddrFormatError as e:
+            raise ValueError(six.text_type(e))
+
+
+class IPV6Network(IPNetwork):
+    @staticmethod
+    def coerce(obj, attr, value):
+        try:
+            return netaddr.IPNetwork(value, version=6)
+        except netaddr.AddrFormatError as e:
+            raise ValueError(six.text_type(e))
+
+
 class CompoundFieldType(FieldType):
     def __init__(self, element_type, **field_args):
         self._element_type = Field(element_type, **field_args)
@@ -617,6 +696,10 @@ class UUIDField(AutoTypedField):
     AUTO_TYPE = UUID()
 
 
+class MACAddressField(AutoTypedField):
+    AUTO_TYPE = MACAddress()
+
+
 class IntegerField(AutoTypedField):
     AUTO_TYPE = Integer()
 
@@ -709,6 +792,30 @@ class ListOfObjectsField(AutoTypedField):
         super(ListOfObjectsField, self).__init__(**kwargs)
 
 
+class IPAddressField(AutoTypedField):
+    AUTO_TYPE = IPAddress()
+
+
+class IPV4AddressField(AutoTypedField):
+    AUTO_TYPE = IPV4Address()
+
+
+class IPV6AddressField(AutoTypedField):
+    AUTO_TYPE = IPV6Address()
+
+
+class IPNetworkField(AutoTypedField):
+    AUTO_TYPE = IPNetwork()
+
+
+class IPV4NetworkField(AutoTypedField):
+    AUTO_TYPE = IPV4Network()
+
+
+class IPV6NetworkField(AutoTypedField):
+    AUTO_TYPE = IPV6Network()
+
+
 class CoercedCollectionMixin(object):
     def __init__(self, *args, **kwargs):
         self._element_type = None
